@@ -33,11 +33,6 @@
         <source>Share</source>
         <translation>Jaa</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="10"/>
-        <source>Change icon</source>
-        <translation>Vaihda kuvake</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Compress</source>
@@ -610,16 +605,6 @@
         <source>Deleting</source>
         <translation>Poistetaan</translation>
     </message>
-    <message>
-        <location filename="../askdialog.cpp" line="10"/>
-        <source>Change icon</source>
-        <translation>Vaihda kuvake</translation>
-    </message>
-    <message>
-        <location filename="../askdialog.cpp" line="10"/>
-        <source>Apply to subfolders?</source>
-        <translation>Käytä alikansiot?</translation>
-    </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Are you sure you want to delete %1?</source>
@@ -703,7 +688,7 @@
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
-                <source>Cancel</source>
+        <source>Cancel</source>
         <translation>Peru</translation>
     </message>
     <message>
@@ -841,7 +826,7 @@
 </context>
 <context>
     <name>UnzipDlg</name>
-        <message>
+    <message>
         <location filename="../unzipdlg.cpp" line="10"/>
         <source>Extract</source>
         <translation>Pura</translation>
@@ -918,12 +903,4 @@
         <translation>Tiedostoselain Maemo 5:lle</translation>
     </message>
 </context>
-<context>
-    <name>selectIcon</name>
-    <message>
-        <location filename="../selecticon.cpp" line="10"/>
-        <source>Select icon</source>
-        <translation>Valitse kuvake</translation>
-    </message>
-</context>
 </TS>
