@@ -21,6 +21,7 @@
 #include "compressdlg.h"
 #include "unzip.h"
 #include "about.h"
+#include "help.h"
 #include "home.h"
 #include "selecticon.h"
 #include "filedelegate.h"
@@ -1668,6 +1669,12 @@ void MainWindow::on_actionAbout_triggered()
     ad->exec();
 }
 
+void MainWindow::on_actionHelp_triggered()
+{
+    Help* hp = new Help(this);
+    hp->exec();
+}
+
 void MainWindow::on_qsearch_clicked()
 {
     ui->search->setText("");
